From mboxrd@z Thu Jan  1 00:00:00 1970
Date: Thu, 24 Jun 2021 19:47:05 -0700
To: Kevin Maciel <kmac613@gmx.com>
Cc: Klemens Nanni <klemens@posteo.de>, list@causal.agency
Subject: Re: TLS handshake failure on Rizon
From: Michael Forney <mforney@mforney.org>
References: <CCATEY96AZ1G.23PYBBGODXI5F@bub> <YNOH4LUDZVEt7iT5@eru>
 <YNThp/2kBatUaWd+@bub>
In-Reply-To: <YNThp/2kBatUaWd+@bub>
Message-Id: <2MTWAP48YXVGE.32VF9XJHAXCV9@mforney.org>
MIME-Version: 1.0
Content-Type: text/plain; charset=UTF-8
Content-Transfer-Encoding: quoted-printable

Kevin Maciel <kmac613@gmx.com> wrote:
> Maybe it would be better if someone more knowledgeable than myself
> reported it to bugs@openbsd.org, but I would be glad to do it if you
> have any suggestions of what I should include in the report. I also have
> no problems connecting to other networks using catgirl. I can ask the
> people in #services about their TLSv1.3 implementation. Let me know if I
> should ask them anything more specific.

You could ask the OpenBSD developers why libtls does not allow ECDHE
with P-521 by default and if they'd be open to changing that. It
looks like this restriction was introduced in [0] which does not
mention P-521 at all, so perhaps it is unintentional.

You could also ask the people managing Rizon why they insist on
P-521, instead of supporting those other curves as well.

Note that this is not really related to TLS 1.2 vs TLS 1.3. In both
cases the ECDHE key exchange method (which should be preferred) is
not getting selected because both sides can't agree on a curve to
use. When you force TLS 1.2 in nc, you'll see that the cipher suite
that gets negotiated is DHE-RSA-AES256-GCM-SHA384 (non-EC DH).

[0] https://github.com/openbsd/src/commit/4896de1e4badc3cc28e3046a4145c9457=
0c197d2

> To Michael Forney,
> Any pointers on how to add this in to catgirl so I can test it? My
> programming knowledge is very rudimentary and I don't really know C, but
> it seems like irc.c is where all the similar stuff is going on, so I
> guess it should go in there somewhere.
>=20
> Thanks!

Untested, but the following should work (on top of catgirl 1.8):

diff --git a/irc.c b/irc.c
index c98193a..024add1 100644
--- a/irc.c
+++ b/irc.c
@@ -57,6 +57,15 @@ void ircConfig(
 		);
 	}
=20
+	// Enable P-521 since libtls disables it by default.
+	error =3D tls_config_set_ecdhecurves(config, "X25519,P-256,P-384,P-521");=

+	if (error) {
+		errx(
+			EX_SOFTWARE, "tls_config_set_ecdhecurves: %s",
+			tls_config_error(config)
+		);
+	}
+
 	if (insecure) {
 		tls_config_insecure_noverifycert(config);
 		tls_config_insecure_noverifyname(config);

